@@ -176,6 +176,16 @@ class RulesCollection(object):
         self.rules = []
         self.all_rules = []
 
+        self.configure(
+            ignore_rules=ignore_rules,
+            include_rules=include_rules,
+            configure_rules=configure_rules,
+            include_experimental=include_experimental,
+            mandatory_rules=mandatory_rules,
+            )
+
+    def configure(self, ignore_rules=None, include_rules=None, configure_rules=None, include_experimental=False, mandatory_rules=None):
+        self.rules = []
         # Whether "experimental" rules should be added
         self.include_experimental = include_experimental
 
@@ -191,14 +201,21 @@ class RulesCollection(object):
             if default_rule not in self.include_rules:
                 self.include_rules.extend([default_rule])
 
-    def register(self, rule):
-        """Register rules"""
-        self.all_rules.append(rule)
+        for rule in self.all_rules:
+            self.__register(rule)
+
+    def __register(self, rule):
+        """ Register and configure the rule """
         if self.is_rule_enabled(rule):
             self.rules.append(rule)
             if rule.id in self.configure_rules:
                 rule.configure(self.configure_rules[rule.id])
 
+    def register(self, rule):
+        """Register rules"""
+        self.all_rules.append(rule)
+        self.__register(rule)
+
     def __iter__(self):
         return iter(self.rules)
 
